# speechall
The Speechall REST API provides powerful and flexible speech-to-text capabilities.
It allows you to transcribe audio files using various underlying STT providers and models,
optionally apply custom text replacement rules, and access results in multiple formats.
The API includes standard endpoints for transcription and endpoints compatible with the OpenAI API structure.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 0.1.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen
For more information, please visit [https://speechall.com/contact](https://speechall.com/contact)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import speechall
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import speechall
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import speechall
from speechall.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.speechall.com/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = speechall.Configuration(
    host = "https://api.speechall.com/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (API Key): bearerAuth
configuration = speechall.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with speechall.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = speechall.ReplacementRulesApi(api_client)
    create_replacement_ruleset_request = {"name":"Acme Corp Corrections","rules":[{"kind":"exact","search":"speechal","replacement":"Speechall","caseSensitive":false},{"kind":"regex","pattern":"\\b(\\d{3})-(\\d{2})-(\\d{4})\\b","replacement":"[REDACTED SSN]","flags":["i"]}]} # CreateReplacementRulesetRequest | JSON object containing the name for the ruleset and an array of replacement rule objects.

    try:
        # Create a reusable set of text replacement rules.
        api_response = api_instance.create_replacement_ruleset(create_replacement_ruleset_request)
        print("The response of ReplacementRulesApi->create_replacement_ruleset:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ReplacementRulesApi->create_replacement_ruleset: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.speechall.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ReplacementRulesApi* | [**create_replacement_ruleset**](docs/ReplacementRulesApi.md#create_replacement_ruleset) | **POST** /replacement-rulesets | Create a reusable set of text replacement rules.
*SpeechToTextApi* | [**list_speech_to_text_models**](docs/SpeechToTextApi.md#list_speech_to_text_models) | **GET** /speech-to-text-models | Retrieve a list of all available speech-to-text models.
*SpeechToTextApi* | [**transcribe**](docs/SpeechToTextApi.md#transcribe) | **POST** /transcribe | Upload an audio file directly and receive a transcription.
*SpeechToTextApi* | [**transcribe_remote**](docs/SpeechToTextApi.md#transcribe_remote) | **POST** /transcribe-remote | Transcribe an audio file located at a remote URL.


## Documentation For Models

 - [BaseTranscriptionConfiguration](docs/BaseTranscriptionConfiguration.md)
 - [CreateReplacementRuleset201Response](docs/CreateReplacementRuleset201Response.md)
 - [CreateReplacementRulesetRequest](docs/CreateReplacementRulesetRequest.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [ExactRule](docs/ExactRule.md)
 - [OpenAICreateTranslationRequestModel](docs/OpenAICreateTranslationRequestModel.md)
 - [OpenaiCompatibleCreateTranscription200Response](docs/OpenaiCompatibleCreateTranscription200Response.md)
 - [OpenaiCompatibleCreateTranslation200Response](docs/OpenaiCompatibleCreateTranslation200Response.md)
 - [RegexGroupRule](docs/RegexGroupRule.md)
 - [RegexRule](docs/RegexRule.md)
 - [RemoteTranscriptionConfiguration](docs/RemoteTranscriptionConfiguration.md)
 - [ReplacementRule](docs/ReplacementRule.md)
 - [SpeechToTextModel](docs/SpeechToTextModel.md)
 - [TranscriptLanguageCode](docs/TranscriptLanguageCode.md)
 - [TranscriptOutputFormat](docs/TranscriptOutputFormat.md)
 - [TranscriptionDetailed](docs/TranscriptionDetailed.md)
 - [TranscriptionModelIdentifier](docs/TranscriptionModelIdentifier.md)
 - [TranscriptionOnlyText](docs/TranscriptionOnlyText.md)
 - [TranscriptionProvider](docs/TranscriptionProvider.md)
 - [TranscriptionResponse](docs/TranscriptionResponse.md)
 - [TranscriptionSegment](docs/TranscriptionSegment.md)
 - [TranscriptionWord](docs/TranscriptionWord.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (API Key)


## Author




